import { NitroConfig } from '../../config/NitroConfig.js';
import { getHybridObjectName } from '../getHybridObjectName.js';
export function createJNIHybridObjectRegistration({ hybridObjectName, jniClassName, }) {
    const { JHybridTSpec } = getHybridObjectName(hybridObjectName);
    const jniNamespace = NitroConfig.getAndroidPackage('c++/jni', jniClassName);
    return {
        requiredImports: [
            { name: `${JHybridTSpec}.hpp`, language: 'c++', space: 'user' },
            {
                name: 'NitroModules/JNISharedPtr.hpp',
                language: 'c++',
                space: 'system',
            },
        ],
        cppCode: `
HybridObjectRegistry::registerHybridObjectConstructor(
  "${hybridObjectName}",
  []() -> std::shared_ptr<HybridObject> {
    static auto javaClass = jni::findClassStatic("${jniNamespace}");
    static auto defaultConstructor = javaClass->getConstructor<${JHybridTSpec}::javaobject()>();

    auto instance = javaClass->newObject(defaultConstructor);
#ifdef NITRO_DEBUG
    if (instance == nullptr) [[unlikely]] {
      throw std::runtime_error("Failed to create an instance of \\"${JHybridTSpec}\\" - the constructor returned null!");
    }
#endif
    auto globalRef = jni::make_global(instance);
    return JNISharedPtr::make_shared_from_jni<${JHybridTSpec}>(globalRef);
  }
);
      `.trim(),
    };
}
