import { NitroConfig } from '../../config/NitroConfig.js';
import { getForwardDeclaration } from '../c++/getForwardDeclaration.js';
import { getHybridObjectName } from '../getHybridObjectName.js';
export class HybridObjectType {
    hybridObjectName;
    implementationLanguage;
    constructor(hybridObjectName, implementationLanguage) {
        this.hybridObjectName = hybridObjectName;
        this.implementationLanguage = implementationLanguage;
        if (this.hybridObjectName.startsWith('__')) {
            throw new Error(`HybridObject name cannot start with two underscores (__)! (In ${this.hybridObjectName})`);
        }
    }
    get canBePassedByReference() {
        // It's a shared_ptr<..>, no copy.
        return true;
    }
    get kind() {
        return 'hybrid-object';
    }
    getCode(language) {
        const name = getHybridObjectName(this.hybridObjectName);
        switch (language) {
            case 'c++': {
                const fullName = NitroConfig.getCxxNamespace('c++', name.HybridTSpec);
                return `std::shared_ptr<${fullName}>`;
            }
            case 'swift': {
                return `(any ${name.HybridTSpec})`;
            }
            case 'kotlin': {
                return name.HybridTSpec;
            }
            default:
                throw new Error(`Language ${language} is not yet supported for HybridObjectType!`);
        }
    }
    getExtraFiles() {
        return [];
    }
    getRequiredImports() {
        const name = getHybridObjectName(this.hybridObjectName);
        const cxxNamespace = NitroConfig.getCxxNamespace('c++');
        return [
            {
                language: 'c++',
                name: 'memory',
                space: 'system',
            },
            {
                name: `${name.HybridTSpec}.hpp`,
                forwardDeclaration: getForwardDeclaration('class', name.HybridTSpec, cxxNamespace),
                language: 'c++',
                space: 'user',
            },
        ];
    }
}
