import {} from '../SourceFile.js';
export class OptionalType {
    wrappingType;
    constructor(wrappingType) {
        this.wrappingType = wrappingType;
    }
    get canBePassedByReference() {
        // depends whether the wrapping type is heavy to copy or not.
        return this.wrappingType.canBePassedByReference;
    }
    get kind() {
        return 'optional';
    }
    getCode(language) {
        const wrapping = this.wrappingType.getCode(language);
        switch (language) {
            case 'c++':
                return `std::optional<${wrapping}>`;
            case 'swift':
                return `${wrapping}?`;
            case 'kotlin':
                return `${wrapping}?`;
            default:
                throw new Error(`Language ${language} is not yet supported for OptionalType!`);
        }
    }
    getExtraFiles() {
        return this.wrappingType.getExtraFiles();
    }
    getRequiredImports() {
        return [
            {
                language: 'c++',
                name: 'optional',
                space: 'system',
            },
            ...this.wrappingType.getRequiredImports(),
        ];
    }
}
