import { isNotDuplicate } from '../helpers.js';
import {} from '../SourceFile.js';
export class VariantType {
    variants;
    constructor(variants) {
        this.variants = variants;
    }
    get canBePassedByReference() {
        // It's a variant<..> - heavy to copy
        return true;
    }
    get kind() {
        return 'variant';
    }
    getCode(language) {
        const types = this.variants
            .map((v) => v.getCode(language))
            .filter(isNotDuplicate);
        switch (language) {
            case 'c++':
                return `std::variant<${types.join(', ')}>`;
            case 'swift':
                return `Variant_${types.join('_')}`;
            case 'kotlin':
                return `Variant_${types.join('_')}`;
            default:
                throw new Error(`Language ${language} is not yet supported for VariantType!`);
        }
    }
    getExtraFiles() {
        return this.variants.flatMap((v) => v.getExtraFiles());
    }
    getRequiredImports() {
        return [
            {
                language: 'c++',
                name: 'variant',
                space: 'system',
            },
            ...this.variants.flatMap((v) => v.getRequiredImports()),
        ];
    }
}
